@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::CheckListEditor;
-$Config::Model::Tk::CheckListEditor::VERSION = '1.356';
+$Config::Model::Tk::CheckListEditor::VERSION = '1.361';
 use strict;
 use warnings;
 use Carp;
@@ -105,7 +105,7 @@ sub Populate {
 
     $cw->ConfigModelNoteEditor( -object => $leaf )->pack(@fbe1);
     $cw->add_summary($leaf)->pack(@fx);
-    $cw->add_description($leaf)->pack(@fx);
+    $cw->add_description($leaf)->pack(@fbe1);
     my ( $help_frame, $help_widget ) = $cw->add_help( value => '', 1 );
     $help_frame->pack(@fx);
     $cw->{value_help_widget} = $help_widget;
