@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::CheckListViewer;
-$Config::Model::Tk::CheckListViewer::VERSION = '1.359';
+$Config::Model::Tk::CheckListViewer::VERSION = '1.361';
 use strict;
 use warnings;
 use Carp;
@@ -101,6 +101,9 @@ sub set_value_help {
     my $w = $cw->{value_help_widget};
     $w->delete( '0.0', 'end' );
 
+    # in pod text, =encoding must be specified only once
+    $w->insert( 'end', "=encoding utf8\n\n");
+
     foreach my $v (@set) {
         my $value_help = $cw->{leaf}->get_help($v);
         $w->insert( 'end', "$v: " . $value_help . "\n" ) if defined $value_help;
