@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2008-2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::HashEditor;
-$Config::Model::Tk::HashEditor::VERSION = '1.351';
+$Config::Model::Tk::HashEditor::VERSION = '1.361';
 use strict;
 use warnings;
 use Carp;
@@ -90,7 +90,8 @@ sub Populate {
     );
     $tklist->pack( @fbe1, -side => 'left' );
     $cw->Advertise( tklist => $tklist );
-    $cw->insert( end => $hash->fetch_all_indexes );
+
+    $cw->reset_value;
 
     my $item_frame = $cw->Frame(qw/-borderwidth 1 -relief groove/)->pack( @fx, -anchor => 'n' );
 
@@ -228,11 +229,18 @@ sub Populate {
     $cw->add_warning( $hash, 'edit' )->pack(@fx);
     $cw->add_info_button()->pack( @fx, qw/-anchor n/ );
     $cw->add_summary($hash)->pack(@fx);
-    $cw->add_description($hash)->pack(@fx);
+    $cw->add_description($hash)->pack(@fbe1);
 
     $cw->Tk::Frame::Populate($args);
 }
 
+sub reset_value {
+    my $cw = shift ;
+    $cw->Subwidget('tklist')->delete( 0, 'end' );
+    $cw->insert( end => $cw->{hash}->fetch_all_indexes );
+}
+
+
 # the following function is used to make multi-line keys (like Files
 # entries in Debian copyright files) more manageable: LF are replaced
 # by \n to enable editing a multi line entry in a Tk::Entry.
