@@ -1,14 +1,14 @@
 #
 # This file is part of Config-Model-TkUI
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2008-2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Tk::NodeEditor;
-$Config::Model::Tk::NodeEditor::VERSION = '1.351';
+$Config::Model::Tk::NodeEditor::VERSION = '1.361';
 use strict;
 use warnings;
 use Carp;
@@ -69,7 +69,7 @@ sub Populate {
 
     if ( $node->parent ) {
         $cw->add_summary($node)->pack(@fx);
-        $cw->add_description($node)->pack(@fx);
+        $cw->add_description($node)->pack(@fbe1);
     }
     else {
         $cw->add_help( class => $node->get_help )->pack(@fx);
@@ -113,7 +113,7 @@ sub fill_pane {
         my $label = $f->Label( -text => $c, -width => 22, -anchor => 'w' );
         $label->pack(qw/-side left -fill x -anchor w/);
 
-        my $help = $node->get_help( summary => $c ) || $node->get_help( description => $c );
+        my $help = $node->get_help_as_text( summary => $c ) || $node->get_help_as_text( description => $c );
         $cw->Balloon( -state => 'balloon' )->attach( $label, -msg => wrap( '', '', $help ) );
 
         if ( $type eq 'leaf' ) {
@@ -154,6 +154,8 @@ sub fill_pane {
         # add button to launch dedicated editor
         my $obj      = $node->fetch_element($c);
         my $edit_sub = sub {
+            # it would be better for tkui ui to pass this as a callback
+            # note that storing tkui object in a sub widget creates issues with tk
             $cw->parent->parent->parent->parent->create_element_widget( 'edit', $elt_path, $obj );
         };
         my $edb = $f->Button(
